clear all
close all

%%% computation of posterior distribution

% alpha= AFR, t0= T0FR, kappa= K

%%% initialize random number generator
rand('state',sum(100*clock));
randn('state',sum(100*clock));

%%% load the data

load data_smooth5

%%% save for // computation

ns=input(['Enter simulation number : ']);
nom=['resBayes_' num2str(ns)]

%%% population size and parameter beta
S0FR=67e6;
beta=1/10;

%%% number of cases per day (based on smoothed data)
IncFR=[0 diff(DATA(1,:))];

%%% number of tests per day
NtFR=[0 diff(DATA(2,:))];


%%% priors (parameter bounds)
%am=0; aM=1; % alpha
%t0m=1; t0M=31; 
%kappam=0; kappaM=1;

% or more informative prior:
am=1.4/10; aM=6.49/10,
t0m=20; t0M=31;
kappam=0; kappaM=1/100;

bl=[am  t0m kappam]; % lower bound
bm=[aM  t0M kappaM ]; % upper bound

%%% proposals (standard deviation)
salpha=1e-3;
skappa=1e-5;
st0=1e-2;

%%% initial guess (obtained from the MLE)
alphaFR=0.32;
t0FR=27;
kappa=3e-4;

AFR(1)=alphaFR;
T0FR(1)=t0FR;
K(1)=kappa;

T=77;
MI=zeros(T,1e6);
MR=zeros(T,1e6);
vFR=zeros(1,1e6);
%%% initial likelihood
cpt=1;

[vFR(cpt) MI(:,cpt) MR(:,cpt)]=vrais_COVID([AFR(cpt) beta],T0FR(cpt),K(cpt),NtFR,IncFR,S0FR);

%%% main loop

arret=0;
cptmax=1e6;
acc=0; % accept rate (for display only)

cptratio=1;
while arret==0
    
    % proposals
    alphaFRb=AFR(cpt)+salpha*randn(1);
    while ((alphaFRb<am)+(alphaFRb>aM))>0
        alphaFRb=AFR(cpt)+salpha*randn(1);
    end
    t0FRb=T0FR(cpt)+st0*randn(1);
    while ((t0FRb<t0m)+(t0FRb>t0M))>0
        t0FRb=T0FR(cpt)+st0*randn(1);
    end
    kappab=K(cpt)+skappa*randn(1);
    while ((kappab<kappam)+(kappab>kappaM))>0
        kappab=K(cpt)+skappa*randn(1);
    end
    
    % compute the likelihood
    [vFRb Ib Rb]=vrais_COVID([alphaFRb beta],t0FRb,kappab,NtFR,IncFR,S0FR);
    
    % accept or reject

    deltav=vFRb-vFR(cpt); % 
    cpt=cpt+1;
    w=rand(1);
    
    % accept rate
    cptratio=cptratio+1;
    if mod(cpt,1e2)==0
            acc=0;
            cptratio=0;
    end
    
    if log(w)<deltav  %accept
        acc=acc+1;
        ratio=acc/cptratio
        AFR(cpt)=alphaFRb;
        T0FR(cpt)=t0FRb;
        K(cpt)=kappab;
        vFR(cpt)=vFRb;
        MI(:,cpt)=Ib;
        MR(:,cpt)=Rb;
    else %reject
        AFR(cpt)=AFR(cpt-1);
        T0FR(cpt)=T0FR(cpt-1);
        K(cpt)=K(cpt-1);
        vFR(cpt)=vFR(cpt-1);
        MI(:,cpt)=MI(:,cpt-1);
        MR(:,cpt)=MR(:,cpt-1);
        
    end
    if mod(cpt,1000)==1
        cpt
        save(nom)
    end
    
    if cpt>cptmax
        arret=1;
    end
    
    
end